@@ -3,21 +3,6 @@
 
 
 
-context("Testing set_parameter_matrix")
-
-testthat::skip_on_cran()
-testthat::test_that(
-
-	desc = "Testing messages.",
-
-	code = {
-		model <- make_model("X <- Y")
-		model <- set_parameter_matrix(model)
-		# P already contained
-		expect_message(set_parameter_matrix(model))
-	}
-)
-
 context("Testing summary commands for set_parameter_matrix")
 
 testthat::skip_on_cran()
